<?php

/**
 * @file
 *   Referral source select component for webform module.
 */

/**
 * Create a default referral source select component.
 */
function _webform_defaults_referralsource() {
  return array(
    'name' => '',
    'form_key' => 'referral_source_select',
    'email' => 1,
    'mandatory' => 0,
    'pid' => 0,
    'weight' => 0,
    'value' => '',
    'extra' => array(
      'items' => '',
      'email' => 0,
      'multiple' => NULL,
      'aslist' => 'Y',
      'description' => '',
    ),
  );
}

/**
 * Create a set of form items to be displayed on the form for editing this
 * component. Use care naming the form items, as this correlates directly to the
 * database schema. The component "Name" and "Description" fields are added to
 * every component type and are not necessary to specify here (although they may
 * be overridden if desired).
 * @return
 *   An array of form items to be displayed on the edit component page.
 */
function _webform_edit_referralsource($currfield) {
  return array();
}

/**
 * Build a form item array containing all the properties of this component.
 * @param $component
 *   An array of information describing the component, directly correlating to
 *   the webform_component database schema.
 * @return
 *   An array of a form item to be displayed on the client-side webform.
 */
function _webform_render_referralsource($component) {
  // Normally the cid isn't included in the form item, but it is being included here so
  // referralsources_webform_client_form_submit() can get to it later.
  $form_item = array(
    '#type'          => 'referralsources_select',
    '#title'         => check_plain($component['name']),
    '#required'      => $component['mandatory'],
    '#weight'        => $component['weight'],
    '#description'   => _webform_filter_descriptions(check_plain($component['extra']['description'])),
    '#default_value' => _webform_filter_values(check_plain($component['value'], NULL, NULL, FALSE)),
    '#prefix'        => '<div class="webform-component-'. $component['type'] .'" id="webform-component-'. $component['form_key'] .'">',
    '#suffix'        => '</div>',
    '#cid'           => $component['cid'],
  );

  return $form_item;
}

/**
 * Display the result of a textfield submission. The output of this function
 * will be displayed under the "results" tab then "submissions".
 * @param $data
 *   An array of information containing the submission result, directly
 *   correlating to the webform_submitted_data database schema.
 * @param $component
 *   An array of information describing the component, directly correlating to
 *   the webform_component database schema.
 * @param $enabled
 *   If enabled, the value may be changed. Otherwise it will set to readonly.
 * @return
 *   Textual output formatted for human reading.
 */
function _webform_submission_display_referralsource($data, $component, $enabled = FALSE) {
  $form_item = _webform_render_referralsource($component);

  // Convert one dimensional $data['value'] array into associative array, and set as
  // default value of component.
  $default_value = array();
  if (isset($data['value'][0])) $default_value['referralsources_rid'] = check_plain($data['value'][0]);
  if (isset($data['value'][1])) $default_value['referralsources_other'] = check_plain($data['value'][1]);
  $form_item['#default_value'] = $default_value;

  $form_item['#disabled'] = !$enabled;
  return $form_item;
}


/**
 * Store submitted values
 *
 * @param $data
 *   The POST data associated with the component.
 * @param $component
 *   An array of information describing the component, directly correlating to
 *   the webform_component database schema.
 */
function _webform_submit_referralsource(&$data, $component) {
  // $data needs to be converted into a one dimensional array so the Webforms module can store it natively.
  $temp = array();
  $temp[0] = $data['referralsources_rid'];
  $temp[1] = $data['referralsources_other'];
  $data = $temp;
}

/**
 * Format the output of emailed data for this component.
 *
 * @param $data
 *   A string or array of the submitted data.
 * @param $component
 *   An array of information describing the component, directly correlating to
 *   the webform_component database schema.
 * @return
 *   Textual output to be included in the email.
 */
function theme_webform_mail_referralsource($data, $component) {
  // Convert submitted 'safe' values to un-edited, original form.
  $options = _webform_referralsource_options(TRUE);

  // Generate the output.
  if ($data[0] == 'OTHER' || (empty($data[0]) && !empty($data[1]))) {
    // "Other" selected, or nothing selected and "other" text entered... show other text.
    $output = $component['name'] .': '. $data[1];
  }
  elseif (isset($options[$data[0]])) {
    // Normal option selected, show name of referral source selection.
    $output = $component['name'] .': '. $options[$data[0]];
  }
  return $output;
}

/**
 * Implementation of Webforms internal theme hook.
 */
function _webform_theme_referralsource() {
  return array(
    'webform_mail_referralsource' => array(
      'arguments' => array('data' => NULL, 'component' => NULL),
    ),
  );
}

/**
 * Calculate and returns statistics about results for this component from all
 * submission to this webform. The output of this function will be displayed
 * under the "results" tab then "analysis".
 * @param $component
 *   An array of information describing the component, directly correlating to
 *   the webform_component database schema
 * @return
 *   An array of data rows, each containing a statistic for this component's
 *   submissions.
 */
function _webform_analysis_rows_referralsource($component) {
  $options = _webform_referralsource_options(TRUE);

  $query = 'SELECT data, count(data) as datacount '.
    ' FROM {webform_submitted_data} '.
    ' WHERE nid = %d '.
    ' AND cid = %d '.
    " AND data != '0' AND data != '' ".
    ' GROUP BY data ';
  $result = db_query($query, $component['nid'], $component['cid']);
  $rows = array();
  while ($data = db_fetch_array($result)) {
    if ($data['data'] == 'OTHER') {
      // Do not display "OTHER" selection in results ("other" text will be displayed)
      continue;
    }
    elseif (isset($options[$data['data']])) {
      // Normal select option value, show name of referral source selection.
      $display_option = $options[$data['data']];
    }
    else {
      // Other text value
      $display_option = $data['data'];
    }
    $rows[] = array($display_option, $data['datacount']);
  }
  return $rows;
}

/**
 * Return the result of this component's submission for display in a table. The
 * output of this function will be displayed under the "results" tab then "table".
 * @param $data
 *   An array of information containing the submission result, directly
 *   correlating to the webform_submitted_data database schema
 * @return
 *   Textual output formatted for human reading.
 */
function _webform_table_data_referralsource($data) {
  $options = _webform_referralsource_options(TRUE);

  if ($data['value'][0] == 'OTHER' || (empty($data['value'][0]) && !empty($data['value'][1]))) {
    // "Other" selected, or nothing selected and "other" text entered... show other text.
    $output = check_plain($data['value'][1]);
  }
  elseif (isset($options[$data['value'][0]])) {
    // Normal option selected, show name of referral source selection.
    $output = check_plain($options[$data['value'][0]]);
  }
  return $output;
}


/**
 * Return the header information for this component to be displayed in a comma
 * seperated value file. The output of this function will be displayed under the
 * "results" tab then "download".
 * @param $component
 *   An array of information describing the component, directly correlating to
 *   the webform_component database schema.
 * @return
 *   An array of data to be displayed in the first three rows of a CSV file, not
 *   including either prefixed or trailing commas.
 */
function _webform_csv_headers_referralsource($component) {
  $headers = array(
    0 => array(),
    1 => array(),
    2 => array(),
  );

  $headers[0][] = '';
  $headers[1][] = '';
  $headers[2][] = $component['name'];
  return $headers;
}

/**
 * Return the result of a textfield submission. The output of this function will
 * be displayed under the "results" tab then "submissions".
 * @param $data
 *   An array of information containing the submission result, directly
 *   correlating to the webform_submitted_data database schema.
 * @return
 *   Textual output formatted for CSV, not including either prefixed or trailing
 *   commas.
 */
function _webform_csv_data_referralsource($data, $component) {
  $options = _webform_referralsource_options(TRUE);

  if ($data['value'][0] == 'OTHER' || (empty($data['value'][0]) && !empty($data['value'][1]))) {
    // "Other" selected, or nothing selected and "other" text entered... show other text.
    $return = t($data['value'][1]);
  }
  elseif (isset($options[$data['value'][0]])) {
    // Normal option selected, show name of referral source selection.
    $return = t($options[$data['value'][0]]);
  }

  return $return;
}

/**
 * Returns array of referral source options.
 *
 * @param $flat
 *   Optional. If specified, return the option array and exclude any optgroups.
 */
function _webform_referralsource_options($flat = FALSE) {
  return referralsources_select_options($flat);
}
